Crate rtlsdr

Crate rtlsdr 

Structs

Device
Device struct

Enums

DirectSampling
DirectSamplingThreshold
LibusbError
RtlsdrError
General error type for rtlsdr operations, which can be either a libusb error or some other unspecified error
Sideband
TunerType

Functions

get_devices
Get all available devices

Type Aliases

Result