pub enum RtlsdrError {
LibusbError(LibusbError),
Unspecified(i32),
}Expand description
General error type for rtlsdr operations, which can be either a libusb error or some other unspecified error
Variants
LibusbError(LibusbError)
Unspecified(i32)